! { dg-do compile }
      SUBROUTINE A14()
        INTEGER I
        I=1
!$OMP PARALLEL SECTIONS
!$OMP SECTION
!$OMP CRITICAL (NAME)
!$OMP PARALLEL
!$OMP SINGLE
                  I=I+1
!$OMP END SINGLE
!$OMP END PARALLEL
!$OMP END CRITICAL (NAME)
!$OMP END PARALLEL SECTIONS
      END SUBROUTINE A14
